package Sidef::Types::Block::Continue {

    sub new {
        bless {}, __PACKAGE__;
    }
}

1;
